@@ -1,4 +1,4 @@
-/* $Id: pkgin.h,v 1.38 2012/07/30 18:22:45 imilh Exp $ */
+/* $Id: pkgin.h,v 1.41 2012/11/17 14:04:13 imilh Exp $ */
 
 /*
  * Copyright (c) 2009, 2010, 2011, 2012 The NetBSD Foundation, Inc.
@@ -100,19 +100,20 @@
 #define PKG_KEEP_CMD 10
 #define PKG_UNKEEP_CMD 11
 #define PKG_SHKP_CMD 12
-#define PKG_SRCH_CMD 13
-#define PKG_CLEAN_CMD 14
-#define PKG_AUTORM_CMD 15
-#define PKG_EXPORT_CMD 16
-#define PKG_IMPORT_CMD 17
-#define PKG_SHPROV_CMD 18
-#define PKG_SHREQ_CMD 19
-#define PKG_SHPKGCONT_CMD 20
-#define PKG_SHPKGDESC_CMD 21
-#define PKG_SHPKGBDEFS_CMD 22
-#define PKG_SHCAT_CMD 23
-#define PKG_SHPCAT_CMD 24
-#define PKG_SHALLCAT_CMD 25
+#define PKG_SHNOKP_CMD 13
+#define PKG_SRCH_CMD 14
+#define PKG_CLEAN_CMD 15
+#define PKG_AUTORM_CMD 16
+#define PKG_EXPORT_CMD 17
+#define PKG_IMPORT_CMD 18
+#define PKG_SHPROV_CMD 19
+#define PKG_SHREQ_CMD 20
+#define PKG_SHPKGCONT_CMD 21
+#define PKG_SHPKGDESC_CMD 22
+#define PKG_SHPKGBDEFS_CMD 23
+#define PKG_SHCAT_CMD 24
+#define PKG_SHPCAT_CMD 25
+#define PKG_SHALLCAT_CMD 26
 #define PKG_GINTO_CMD 255
 
 #define PKG_EQUAL '='
@@ -121,8 +122,6 @@
 
 #define DEFAULT_NO 0
 #define DEFAULT_YES 1
-#define ANSW_NO 0
-#define ANSW_YES 1
 
 #define TRACE(fmt...) if (tracefp != NULL) fprintf(tracefp, fmt)
 
@@ -196,8 +195,6 @@ typedef struct Plistnumbered {
 	int	P_count;
 } Plistnumbered;
 
-extern uint8_t 		yesflag;
-extern uint8_t 		noflag;
 extern uint8_t 		force_update;
 extern uint8_t 		force_reinstall;
 extern uint8_t		verbosity;
@@ -242,7 +239,6 @@ void		show_category(char *);
 void		show_pkg_category(char *);
 void		show_all_categories(void);
 /* actions.c */
-int			check_yesno(uint8_t);
 void		do_pkg_remove(Plisthead *);
 int			pkgin_remove(char **);
 int			pkgin_install(char **, uint8_t);
@@ -259,10 +255,12 @@ Plisthead	*pkg_impact(char **);
 /* autoremove.c */
 void	   	pkgin_autoremove(void);
 void		show_pkg_keep(void);
+void		show_pkg_nokeep(void);
 int			pkg_is_kept(Pkglist *);
 void		pkg_keep(int, char **);
 /* fsops.c */
 int			fs_has_room(const char *, int64_t);
+uint64_t		fs_room(const char *);
 void		clean_cache(void);
 void		create_dirs(void);
 char		*read_repos(void);
